Unit Square;
{ Square drawing facilities }

Interface
{-------------------------------------------------}

Uses Crt; { For drawing on the screen }

Function On_screen(X, Y: Integer): Boolean;
   { Returns True if the given coordinates are on-screen, }
   { returns False otherwise }

Procedure Draw_char(X, Y: Integer; A_char: Char);
   { Draws the character A_char at the coordinates (X, Y) }
   { Does nothing if the coordinates are off-screen }

Procedure Draw_square(Origin_x, Origin_y, Side: Integer; Border: Char);
   { Draws a square whose top left corner is at }
   { (Origin_x, Origin_y), whose side is of length }
   { Side, and whose border is comprised of Border }
   { characers. Parts of the square which are off-screen }
   { are clipped. }

Implementation
{-------------------------------------------------}

Function On_screen(X, Y: Integer): Boolean;
   { Returns True if the given coordinates are on-screen, }
   { returns False otherwise }
   Const
      { Mark screen dimensions as constants }
      Screen_height = 25;
      Screen_width = 80;
   Var
      X_ok, Y_ok: Boolean; { Test results }
   Begin
      X_ok := (X >= 1) And (X <= Screen_width);    { Is X on-screen? }
      Y_ok := (Y >= 1) And (Y <= Screen_height);   { Is Y on-screen? }
      On_screen := X_ok And Y_ok    { Are the coordinates on-screen? }
   End;

Procedure Draw_char(X, Y: Integer; A_char: Char);
   { Draws the character A_char at the coordinates (X, Y) }
   { Does nothing if the coordinates are off-screen }
   Begin
   If On_screen(X, Y) Then    { Only draw if on-screen }
      Begin
      GotoXY(X, Y);  { Goto the coordinates }
      Write(A_char)  { Draw the character }
      End
   End;

Procedure Draw_square(Origin_x, Origin_y, Side: Integer; Border: Char);
   { Draws a square whose top left corner is at }
   { (Origin_x, Origin_y), whose side is of length }
   { Side, and whose border is comprised of Border }
   { characers. Parts of the square which are off-screen }
   { are clipped. }
   Var
      Index: Integer; { For loop index }
   Begin
   { Draw the edges of the square clockwise }
   For Index := Origin_x To Origin_x + Side - 1 Do
      Begin
      Draw_char(Index, Origin_y, Border);
      End;
   For Index := Origin_y + 1 To Origin_y + Side - 1 Do
      Begin
      Draw_char(Origin_x + Side - 1, Index, Border);
      End;
   For Index := Origin_x + Side - 2 Downto Origin_x Do
      Begin
      Draw_char(Index, Origin_y + Side - 1, Border);
      End;
   For Index := Origin_y + Side - 2 Downto Origin_y + 1 Do
      Begin
      Draw_char(Origin_x, Index, Border);
      End
   End;

{---------------------------------------------------}
End.
