Unit RecSqu;
{ Square drawing facilities using a record type for coordinates }

Interface
{-------------------------------------------------}

Uses Crt; { For drawing on the screen }

Type
   Coord = Record    { Regular 2D coordinates }
      X, Y: Integer
      End;

Function On_screen(Position: Coord): Boolean;
   { Returns True if Position is on-screen, }
   { returns False otherwise }

Procedure Draw_char(Position: Coord; A_char: Char);
   { Draws the character A_char at Position }
   { Does nothing if Position is off-screen }

Procedure Draw_square(Origin: Coord; Side: Integer; Border: Char);
   { Draws a square whose top left corner is at }
   { Origin, whose side is of length }
   { Side, and whose border is comprised of Border }
   { characers. Parts of the square which are off-screen }
   { are clipped. }

Implementation
{-------------------------------------------------}
Function On_screen(Position: Coord): Boolean;
   { Returns True if Position is on-screen, }
   { returns False otherwise }
   Const
      { Mark screen dimensions as constants }
      Screen_height = 25;
      Screen_width = 80;
   Var
      X_ok, Y_ok, Will_scroll: Boolean; { Test results }
   Begin
     With Position Do
       Begin
       X_ok := (X >= 1) And (X <= Screen_width);  { Is X on screen? }
       Y_ok := (Y >= 1) And (Y <= Screen_height); { Is Y on screen? }
       Will_scroll := (X = Screen_width)      { Would they cause scrolling? }
                        And
                        (Y = Screen_height);
         End;
      On_screen := X_ok And Y_ok And Not Will_Scroll
   End;
Procedure Draw_char(Position: Coord; A_char: Char);
   { Draws the character A_char at Position }
   { Does nothing if Position is off-screen }
   Begin
   If On_screen(Position) Then         { Only draw if on-screen }
      Begin
      GotoXY(Position.X, Position.Y);  { Goto the coordinates }
      Write(A_char)                    { Draw the character }
      End
   End;
Procedure Draw_square(Origin: Coord; Side: Integer; Border: Char);
   { Draws a square whose top left corner is at }
   { Origin, whose side is of length }
   { Side, and whose border is comprised of Border }
   { characers. Parts of the square which are off-screen }
   { are clipped. }
   Var
      Index: Integer; { For loop index }
      Pos: Coord;     { For building a coordinate }
   Begin
   With Origin Do
      Begin

      { Draw the edges of the square clockwise }

      Pos.Y := Y;
      For Index := X To X + Side - 1 Do
         Begin
         Pos.X := Index;
         Draw_char(Pos, Border);
         End;

      Pos.X := X + Side - 1;
      For Index := Y + 1 To Y + Side - 1 Do
         Begin
         Pos.Y := Index;
         Draw_char(Pos, Border);
         End;

      Pos.Y := Y + Side - 1;
      For Index := X + Side - 2 Downto X Do
         Begin
         Pos.X := Index;
         Draw_char(Pos, Border);
         End;

      Pos.X := X;
      For Index := Y + Side - 2 Downto Y + 1 Do
         Begin
         Pos.Y := Index;
         Draw_char(Pos, Border);
         End

      End
   End;

{---------------------------------------------------}
End.
